<?php
if ( ! function_exists( 'richwp_comment_nav' ) ) :
/**
 * Display navigation to next/previous comments when applicable.
 */
function richwp_comment_nav() {
	// Are there comments to navigate through?
	if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
	?>
	<nav class="navigation comment-navigation">
		<h2 class="screen-reader-text"><?php _e( 'Comment navigation', 'video-world' ); ?></h2>
		<div class="nav-links">
			<?php
				if ( $prev_link = get_previous_comments_link( __( 'Older Comments', 'video-world' ) ) ) :
					printf( '<div class="nav-previous">%s</div>', $prev_link );
				endif;

				if ( $next_link = get_next_comments_link( __( 'Newer Comments', 'video-world' ) ) ) :
					printf( '<div class="nav-next">%s</div>', $next_link );
				endif;
			?>
		</div><!-- .nav-links -->
	</nav><!-- .comment-navigation -->
	<?php
	endif;
}
endif;

if ( ! function_exists( 'richwp_entry_meta' ) ) :
/**
 * Prints HTML with meta information for the categories, tags.
 */
function richwp_entry_meta() {

	if ( 'post' == get_post_type() ) {
		echo '<footer class="entry-footer">';
		$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'video-world' ) );
		if ( $categories_list ) {
			printf( '<span class="cat-links"><span class="screen-reader-text">%1$s </span>%2$s</span>',
				_x( 'Categories', 'Used before category names.', 'video-world' ),
				$categories_list
			);
		}
		
		if( $tags = get_the_tags() ) {
			echo '<span class="tag-links"><span class="screen-reader-text">' . __( 'Tags', 'video-world' ). '</span>';
			foreach( $tags as $tag ) {
			$sep = ( $tag === end( $tags ) ) ? '' : ' ';
			echo '<a href="' . get_term_link( $tag, $tag->taxonomy ) . '">#' . $tag->name . '</a>' . $sep;
    		}
    		echo '</span>';
		}
		echo '</footer><!-- .entry-footer --> ';
	}

	if ( is_attachment() && wp_attachment_is_image() ) {
		// Retrieve attachment metadata.
		$metadata = wp_get_attachment_metadata();

		printf( '<span class="full-size-link"><span class="screen-reader-text">%1$s </span><a href="%2$s">%3$s &times; %4$s</a></span>',
			_x( 'Full size', 'Used before full size attachment link.', 'video-world' ),
			esc_url( wp_get_attachment_url() ),
			$metadata['width'],
			$metadata['height']
		);
	}

	
}
endif;

if ( ! function_exists( 'richwp_entry_meta_date' ) ) :
/**
 * Prints HTML with date/time information.
 */
function richwp_entry_meta_date() {
	if ( in_array( get_post_type(), array( 'post', 'attachment' ) ) ) {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			get_the_date(),
			esc_attr( get_the_modified_date( 'c' ) ),
			get_the_modified_date()
		);

		printf( '<div class="posted-on"><span class="screen-reader-text">%1$s </span><a href="%2$s" rel="bookmark">%3$s</a></div>',
			_x( 'Posted on', 'Used before publish date.', 'video-world' ),
			esc_url( get_permalink() ),
			$time_string
		);
	}
	
}
endif;


if ( ! function_exists( 'rich_selects' ) ) :
	function rich_selects() {

		if ( has_nav_menu( 'selectmenu1' ) || has_nav_menu( 'selectmenu2' )) {
			$menu_location1 = 'selectmenu1';
			$menu_locations1 = get_nav_menu_locations();
			$menu_object1 = (isset($menu_locations1[$menu_location1]) ? wp_get_nav_menu_object($menu_locations1[$menu_location1]) : null);
			$menu_name1 = (isset($menu_object1->name) ? $menu_object1->name : '');

			echo'<div class="selectwrap">';
			if ( has_nav_menu( 'selectmenu1' ) ) {
			echo'<ul id="selectmenu1" class="richselectmenu">';
					wp_nav_menu( array( 'container' => false, 'fallback_cb' => false, 'items_wrap' => '%3$s', 'menu_id' => 'selectmenu1', 'menu_class' => 'richselectmenu', 'theme_location' => 'selectmenu1', 'depth' => -1 ) ); 
										
					echo'<li><a href="#">';
					echo esc_html($menu_name1);
					echo'</a></li>  
					</ul>';
		};
			
		if ( has_nav_menu( 'selectmenu2' ) ) {
			$menu_location2 = 'selectmenu2';
			$menu_locations2 = get_nav_menu_locations();
			$menu_object2 = (isset($menu_locations2[$menu_location2]) ? wp_get_nav_menu_object($menu_locations2[$menu_location2]) : null);
			$menu_name2 = (isset($menu_object2->name) ? $menu_object2->name : '');
			echo'<ul id="selectmenu2" class="richselectmenu2">';
					wp_nav_menu( array( 'container' => false, 'fallback_cb' => false, 'items_wrap' => '%3$s', 'menu_id' => 'selectmenu2', 'menu_class' => 'richselectmenu', 'theme_location' => 'selectmenu2', 'depth' => -1 ) ); 
										
					echo'<li><a href="#">';
					echo esc_html($menu_name2);
					echo'</a></li>  
					</ul>';
		};
		
		echo '</div>';
		
		}  
		}
endif;




if ( ! function_exists( 'richwp_post_thumbnail' ) ) :
/**
 * Display an optional post thumbnail.
 */
function richwp_post_thumbnail() {
	if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
		return;
	}
	?>



	<div class="loop-thumbnail">
		<a class="post-thumbnail-link" href="<?php the_permalink(); ?>" aria-hidden="true">
		<?php
			the_post_thumbnail( 'post-thumbnail', array( 'alt' => get_the_title() ) );
		?>
		</a>
	</div>

	<?php 
}
endif;

if ( ! function_exists( 'richwp_get_link_url' ) ) :
/**
 * Return the post URL.
 *
 * Falls back to the post permalink if no URL is found in the post.
 *
 * @see get_url_in_content()
 *
 * @return string The Link format URL.
 */
function richwp_get_link_url() {
	$has_url = get_url_in_content( get_the_content() );

	return $has_url ? $has_url : apply_filters( 'the_permalink', get_permalink() );
}
endif;

if ( ! function_exists( 'richwp_excerpt_more' ) && ! is_admin() ) :
/**
Excerpt with 'Continue reading' link.
 */
function richwp_excerpt_more( $more ) {
	$link = sprintf( '<a href="%1$s" class="more-link">%2$s</a>',
		esc_url( get_permalink( get_the_ID() ) ),
		/* translators: %s: Name of current post */
		sprintf( __( 'Continue reading %s', 'video-world' ), '<span class="screen-reader-text">' . get_the_title( get_the_ID() ) . '</span>' )
		);
	return ' &hellip; ' . $link;
}
add_filter( 'excerpt_more', 'richwp_excerpt_more' );
endif;


